Bifrost: Data Fields - Variables

Bifrost

- build : CDBG_Build_opt
- clipTips : CDBG_Build_opt
- data : Unitig< T >
- deleteIsolated : CDBG_Build_opt
- dist : UnitigMapBase
- filename_colors_in : CCDBG_Build_opt
- filename_graph_in : CDBG_Build_opt
- filename_ref_in : CDBG_Build_opt
- filename_seq_in : CDBG_Build_opt
- g : CDBG_Build_opt
- inFilenameBBF : CDBG_Build_opt
- isEmpty : UnitigMapBase
- k : CDBG_Build_opt
- len : UnitigMapBase
- nb_bits_non_unique_kmers_bf : CDBG_Build_opt
- nb_bits_unique_kmers_bf : CDBG_Build_opt
- nb_threads : CDBG_Build_opt
- outFilenameBBF : CDBG_Build_opt
- outputColors : CCDBG_Build_opt
- outputGFA : CDBG_Build_opt
- prefixFilenameOut : CDBG_Build_opt
- read_chunksize : CDBG_Build_opt
- size : UnitigMapBase
- strand : UnitigMapBase
- update : CDBG_Build_opt
- useMercyKmers : CDBG_Build_opt
- verbose : CDBG_Build_opt